@@ -30,12 +30,11 @@ class App:
     def icon(self):
         return load_noimage_app()
 
-    def __init__(self, name, path, package, project_dir=None, project_root_dir=None, install_dir=os.path.dirname(__file__), **kwargs):
-        self.screen_name = name
+    def __init__(self, screen_name, path, package, project_dir=None, install_dir=os.path.dirname(__file__), **kwargs):
+        self.screen_name = screen_name
         self.path = path
         self.package = package
         self.project_dir = Path(project_dir)
-        self.project_root_dir = Path(project_root_dir)
         self.install_dir = Path(install_dir)
         self.params = kwargs
         self.router._app = self
@@ -166,7 +165,7 @@ class App:
 def _session_middleware():
     import base64
 
-    from cryptography import fernet
+    from Crypto.Random import get_random_bytes
 
     from mitama.app import Middleware
     from mitama.app.http.session import EncryptedCookieStorage
@@ -177,7 +176,7 @@ def _session_middleware():
         with open(".tmp/MITAMA_SESSION_KEY", "r") as f:
             session_key = f.read()
     else:
-        key = fernet.Fernet.generate_key()
+        key = get_random_bytes(16)
         session_key = base64.urlsafe_b64encode(key).decode("utf-8")
         if not os.path.exists(".tmp"):
             os.mkdir(".tmp")
